@@ -71,7 +71,7 @@ let gSmtpManager = Cc["@mozilla.org/messengercompose/smtp;1"]
                    .getService(Ci.nsISmtpService);
 let gAccountMgr = Cc["@mozilla.org/messenger/account-manager;1"]
                   .getService(Ci.nsIMsgAccountManager);
-let gEmailWizardLogger = Log4Moz.getConfiguredLogger("emailwizard");
+let gEmailWizardLogger = Log4Moz.getConfiguredLogger("mail.wizard");
 let gStringsBundle;
 let gBrandBundle;
 
@@ -172,7 +172,7 @@ EmailConfigWizard.prototype =
 
     this.showConfigDetails();
 
-    this._domain = this._email.split("@")[1];
+    this._domain = this._email.split("@")[1].toLowerCase();
     this.findConfig(this._domain, this._email);
 
     // swap out buttons
@@ -721,7 +721,11 @@ EmailConfigWizard.prototype =
         // no certificate or cleartext issues
         this.validateAndFinish();
       }
-    } catch (ex) { alertPrompt(gStringsBundle.getString("error_creating_account"), ex); }
+    } catch (ex) {
+      gEmailWizardLogger.error("Error creating account.  ex=" + ex +
+                               ", stack=" + ex.stack);
+      alertPrompt(gStringsBundle.getString("error_creating_account"), ex);
+    }
   },
 
   getMeOutOfHere : function()
@@ -766,13 +770,18 @@ EmailConfigWizard.prototype =
     document.getElementById('create_button').disabled = true;
     var me = this;
     if (!this._verifiedConfig)
-      this.verifyConfig(function() // success
+      this.verifyConfig(function(successfulConfig) // success
                         {
+                          // the incoming auth might have changed, so we
+                          // should back-port it to the current config.
+                          me._currentConfigFilledIn.incoming.auth =
+                              successfulConfig.incoming.auth;
                           me.finish();
                         },
                         function(e) // failure
                         {
                           document.getElementById('create_button').disabled = false;
+                          me.editConfigDetails();
                         });
     else
       this.finish();
@@ -788,20 +797,19 @@ EmailConfigWizard.prototype =
       // guess login config?
       this._currentConfigFilledIn.source != AccountConfig.kSourceXML,
       this._parentMsgWindow,
-      function() // success
+      function(successfulServer) // success
       {
         me._verifiedConfig = true;
         if (me._currentConfigFilledIn.incoming.password)
           me.stopSpinner("password_ok");
         if (successCallback)
-          successCallback();
+          successCallback(successfulServer);
       },
       function(e) // failed
       {
         me.stopSpinner("config_unverifiable");
+        me._updateSpinner("username", true);
         me.setError('passworderror', 'user_pass_invalid');
-        alertPrompt(gStringsBundle.getString("error_creating_account"),
-                    gStringsBundle.getString("config_unverifiable"));
         if (errorCallback)
           errorCallback(e);
       });
@@ -878,7 +886,9 @@ EmailConfigWizard.prototype =
     {
       config.outgoing.username = document.getElementById("username").value;
       config.outgoing.hostname =
-        document.getElementById("outgoing_server").value;
+        sanitize.hostname(document.getElementById("outgoing_server").value);
+      document.getElementById("outgoing_server").value =
+        config.outgoing.hostname;
       config.outgoing.port =
         sanitize.integerRange(document.getElementById("outgoing_port").value, 1,
                               kHighestPort);
@@ -886,7 +896,9 @@ EmailConfigWizard.prototype =
         parseInt(document.getElementById("outgoing_security").value);
     }
     config.incoming.username = document.getElementById("username").value;
-    config.incoming.hostname = document.getElementById("incoming_server").value;
+    config.incoming.hostname =
+      sanitize.hostname(document.getElementById("incoming_server").value);
+    document.getElementById("incoming_server").value = config.incoming.hostname;
     config.incoming.port =
       sanitize.integerRange(document.getElementById("incoming_port").value, 1,
                             kHighestPort);
@@ -1055,7 +1067,7 @@ EmailConfigWizard.prototype =
   },
 
   // IDs of <textbox> inputs that can have a .value attr set
-  _configDetailTextInputs : ["password", "username", "incoming_server",
+  _configDetailTextInputs : ["username", "incoming_server",
                              "incoming_port", "incoming_protocol",
                              "outgoing_port"],
 
@@ -1070,7 +1082,8 @@ EmailConfigWizard.prototype =
   _disableConfigDetails : function(disabled)
   {
     let formElements =
-      this._configDetailTextInputs.concat(this._configDetailMenulists);
+      this._configDetailTextInputs.concat(this._configDetailMenulists)
+                                  .concat("password");
     for (let i = 0; i < formElements.length; i++)
     {
       document.getElementById(formElements[i]).disabled = disabled;
@@ -1091,7 +1104,6 @@ EmailConfigWizard.prototype =
     if (config.incoming.username)
     {
       document.getElementById("username").value = config.incoming.username;
-      this._setIconAndTooltip("username", "strong", "");
     }
     else
     {
@@ -1264,7 +1276,6 @@ EmailConfigWizard.prototype =
   {
     this._showStatusTitle(false, actionStrName);
     if (which == "all") {
-      this._setIconAndTooltip("username", "hidden", "");
       this._setIconAndTooltip("incoming", "hidden", "");
       this._setIconAndTooltip("outgoing", "hidden", "");
     }
@@ -1276,7 +1287,6 @@ EmailConfigWizard.prototype =
   stopSpinner: function(actionStrName)
   {
     this._showStatusTitle(true, actionStrName);
-    this._updateSpinner("username", true);
     this._updateSpinner("incoming", true);
     this._updateSpinner("outgoing", true);
     gEmailWizardLogger.warn("all spinner stop " + actionStrName);
